@@ -6,7 +6,7 @@ Created on 18 sept. 2009
 '''
 
 from obitools.options import getOptionManager
-from obitools.format.options import addInOutputOption, printOutput
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 from obitools.utils import deprecatedScript
 
 
@@ -23,6 +23,7 @@ if __name__ == '__main__':
                                     
     
     (options, entries) = optionParser()
+    writer = sequenceWriterGenerator(options)
     
     for entry in entries:
-        print printOutput(options,entry)
\ No newline at end of file
+        print writer(options,entry)
\ No newline at end of file
