@@ -1,8 +1,115 @@
 #!/usr/local/bin/python
 '''
-Created on 15 janv. 2010
+:py:mod:`ngsfilter` : Assigning reads to their experiments based on DNA tags and primers
+========================================================================================
 
-@author: coissac
+.. codeauthor:: Eric Coissac <eric.coissac@metabarcoding.org>
+
+A DNA metabarcoding experiment can be considered as a set a PCR products mixed together and sequenced using a next generation sequencer ({i.e.} a solexa or a 454).
+To distinguish between this different PCR products, pairs of small DNA sequences (call tags, see the :py:mod:`oligoTag` command and its associated paper for more 
+informations on the design of such tags) unique for each PCR products are concatenated to the PCR primers.
+As they are amplified during the PCR, these tags should be recognizable, together with their respective primers, at the beginning and the end of the reads. 
+The first step in data analysis is thus to demultiplex the large resulting sequence file by identifying these DNA tags and the primers.
+
+Usually the results of sequencing are stored in one or more files formatted according to the fasta or fastq format. :py:mod:`ngsfilter` take as input such sequence file and an extra file describing the DNA tags and primers sequences used for each sample.
+
+The results consist of sequences trimmed of the primers and tags and annotated with the corresponding sample (and possibly some extra informations). 
+Sequences for which the tags and primers have not been well identified, and which are thus unassigned to any sample, are tagged as erroneous sequences 
+by :py:mod:`ngsfilter`. Such erroneous sequences are not reported by the program unless specified by the appropriate option.
+
+
+
+Input files format
+------------------
+
+Sequences data files
+^^^^^^^^^^^^^^^^^^^^
+
+Data returned by next generation sequencers follow mainly two formats. 
+Solexa systems return their data as a `FASTQ <http://en.wikipedia.org/wiki/FASTQ_format>`_ formatted file including sequence data themselves and the associated quality data computed by the sequencer. 
+
+.. code-block:: bash
+
+   @HELIUM_000100422_612GNAAXX:1:1:1176:13188#0/1
+   TACCCCACTATGCTTAGCCCTAAACCTAGATCGTTAGCTCAAACAAAACTATCCGCCAGAGAACTACTAGCAACAGCTTACAACTCAAAGGACTTGGCGGTGCTTTAC
+   +HELIUM_000100422_612GNAAXX:1:1:1176:13188#0/1
+   a^aa^`````^[R^`_aaaaa[aaaa`a`a]KMZ]`^\a`aX`aaPRVV]``P``XXLXLNHNNO`Y``O^^[^BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB
+   @HELIUM_000100422_612GNAAXX:1:1:1176:9252#0/1
+   CCATGATCATTAGATACCCCACTATGCTTAGCCCTAAACACAAATAATTACAAAAACAAAATTATTCGCTAGAGTACTACCGACACCAGTCCGAAACACAAAGACCTG
+   +HELIUM_000100422_612GNAAXX:1:1:1176:9252#0/1
+   WXXXVX^Z[`aaaaaaaaaaaaaaaaaaaaaaaaaaaaaY^^^^[aaaaa`aaaaYZZZZZZG^aBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB
+   @HELIUM_000100422_612GNAAXX:1:1:1176:1609#0/1
+   CCGATTCTATAGAACAGGCTCCTCTAGAGGGGTGTAAAGCACCGCCAAGTCCTTTGAGTTTTAAGCTGTTGCTAGTAGTTCTCTGGCGGATAGTTTTGTTTGAGCTCA
+   +HELIUM_000100422_612GNAAXX:1:1:1176:1609#0/1
+   ^^`]\`bbbbbbbbbbbbbbbbbbbbbabbbbcbbbbbbbbbbbbbbbbbbbbbbbabbbbb`babbbbaabb`bbb^[Ya]Y]]bbbXSbaa^b__\bBBBBBBBBB
+
+
+The 454/Roche system provides the same data in two files. A file named with the extention '.fna' containing the sequence in 
+`FASTA <http://en.wikipedia.org/wiki/FASTA_format>`_ format and a second file named with the extension '.qual' containing the quality score. 
+
+Example of sequences from a 454/Roche output in fasta:
+
+.. code-block:: bash
+
+   >000140_3268_4049 length=85 uaccno=FIBZJ9Q02H89WJ
+   CCGGAAGGGCAATCCTGAGCCAACTCCGTGGAGTACGGTCGCGACCGAGAACGCGATGAT
+   AGGTGCAGAGACTCAATGGTTCCGG
+   >000149_2785_1081 length=60 uaccno=FIBZJ9Q02G2S3F
+   GAACTGGGCAATCCTGAGCCAAATTCTACCTAGGANAGGTGCAGAGACTCAATGGTAGTT
+   >000191_2786_0335 length=65 uaccno=FIBZJ9Q02G2VOH
+   CGAATCGAGCAATCCTGAGCCAAGTCCAAACCATCGGGATAGGTGCAGAGACTCAATGGG
+   ATTCG
+
+Example of quality indices for the 3 sequences above:
+
+.. code-block:: bash
+
+   >000140_3268_4049 length=85 uaccno=FIBZJ9Q02H89WJ
+   35 35 35 35 37 37 32 32 32 37 37 37 37 37 37 37 37 37 40 40 40 40 40 40 40 40 40 40 40 40 40 40 40 40 40 40 38 38 38 39 40 40 40 40 40 37 37 37 37 37 37 37 37 37 37 37 37 37 37 37 
+   37 37 37 37 37 37 37 37 37 37 37 37 37 37 36 36 36 37 37 37 37 37 37 37 37 
+   >000149_2785_1081 length=60 uaccno=FIBZJ9Q02G2S3F
+   37 37 36 33 30 30 30 36 37 37 37 37 37 37 37 37 37 37 38 38 33 33 33 37 37 39 37 37 37 37 37 37 37 38 38 0  38 38 40 40 40 40 40 40 40 37 37 37 37 37 37 37 37 37 37 37 37 37 37 37 
+   >000191_2786_0335 length=65 uaccno=FIBZJ9Q02G2VOH
+   35 35 35 35 35 35 35 35 35 35 35 35 35 35 35 35 35 35 37 35 35 35 35 32 32 33 33 25 21 21 31 31 35 35 35 35 33 33 33 32 32 35 35 35 35 35 35 35 35 35 35 35 35 34 33 33 33 34 34 34 
+   35 25 25 26 34 
+
+
+:py:mod:`ngsfilter` can process both the fasta or the fastq format. If fasta format is used, it can optionally use the '.qual' file to take quality into account. 
+According if the input data contain quality or not, the output of :py:mod:`ngsfilter` will be formatted by default in fastq or fasta format respectively.
+
+
+Sample description data files
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+Samples are assigned based on their DNA tag and primer sequences. :py:mod:`ngsfilter` needs a description of the primers and tags associated to each sample. 
+This is done by mean of the sample description data file. The sample description file is a text file where each line describes one sample. 
+Column are separated by space or tab characters
+
+
+
+Commentaries can also be inserted in the sample description file. Lines beginning with the '#' character will be considered as commentary lines 
+and will simply be ignored by :py:mod:`ngsfilter`.
+
+.. code-block:: bash
+
+    tab=ColumnFile(filename,strip=True,
+                            types=(str,str,tagpair,lower,lower,bool),
+                            head=('experiment','sample',
+                                  'tags',
+                                  'forward_primer','reverse_primer',
+                                  'partial'),
+                            skip="#",
+                            extra="@")
+    
+
+.. code-block:: bash
+
+    gh     01_11a     cacgcagtc    GGGCAATCCTGAGCCAA    CCATTGAGTCTCTGCACCTATC    F @ community=Festuca;   locality=1;  bucket=1; extraction=1; pcr=1; 
+    gh     01_12a     cacgcatcg    GGGCAATCCTGAGCCAA    CCATTGAGTCTCTGCACCTATC    F @ community=Festuca;   locality=1;  bucket=1; extraction=2; pcr=1; 
+    gh     01_21a     cacgcgcat    GGGCAATCCTGAGCCAA    CCATTGAGTCTCTGCACCTATC    F @ community=Festuca;   locality=1;  bucket=2; extraction=1; pcr=1; 
+    gh     01_22a     cacgctact    GGGCAATCCTGAGCCAA    CCATTGAGTCTCTGCACCTATC    F @ community=Festuca;   locality=1;  bucket=2; extraction=2; pcr=1; 
+    gh     02_11a     cacgctgag    GGGCAATCCTGAGCCAA    CCATTGAGTCTCTGCACCTATC    F @ community=Festuca;   locality=2;  bucket=1; extraction=1; pcr=1;
+    gh     02_12a     cacgtacga    GGGCAATCCTGAGCCAA    CCATTGAGTCTCTGCACCTATC    F @ community=Festuca;   locality=2;  bucket=1; extraction=2; pcr=1;
 '''
 from obitools import NucSequence, DNAComplementSequence
 from string import lower
@@ -132,16 +239,19 @@ class Primer:
             score = ali.score
             start = ali[1].gaps[0][1]
             end = len(ali[1])-ali[1].gaps[-1][1]
-            if isinstance(self.sequence, DNAComplementSequence):
-                if (len(sequence)-end) >= self.taglength:
-                    tag=str(sequence[end:end+self.taglength].complement())
+            if self.taglength is not None:
+                if isinstance(self.sequence, DNAComplementSequence):
+                    if (len(sequence)-end) >= self.taglength:
+                        tag=str(sequence[end:end+self.taglength].complement())
+                    else:
+                        tag=None
                 else:
-                    tag=None
+                    if start >= self.taglength:                
+                        tag=str(sequence[start - self.taglength:start])
+                    else:
+                        tag=None
             else:
-                if start >= self.taglength:                
-                    tag=str(sequence[start - self.taglength:start])
-                else:
-                    tag=None
+                tag=None
                 
             return score,start,end,tag
 
@@ -183,7 +293,7 @@ def readTagfile(filename):
 
     for p in tab:
         forward=Primer(p['forward_primer'],
-                       len(p['tags'][0]),
+                       len(p['tags'][0]) if p['tags'][0]!='-' else None,
                        True,
                        error=options.error)
         
@@ -191,7 +301,7 @@ def readTagfile(filename):
         primers[forward]=fp
         
         reverse=Primer(p['reverse_primer'],
-                       len(p['tags'][1]),
+                       len(p['tags'][1]) if p['tags'][1]!='-' else None,
                        False,
                        error=options.error)
         
@@ -310,6 +420,7 @@ def annotate(sequence,options):
             message = 'No reverse primer match'
         else:
             message = 'No direct primer match'
+            sequence=sequence.complement()
                   
         sequence['error']=message
         return False,sequence
@@ -442,4 +553,4 @@ if __name__ == '__main__':
             unidentified(seq)
             
     
-    
\ No newline at end of file
+    
