@@ -1,8 +1,20 @@
 #!/usr/local/bin/python
 '''
-Created on 15 dec. 2009
+:py:mod:`obihead` : Extract the first sequences
+===============================================
+
+.. codeauthor:: Eric Coissac <eric.coissac@metabarcoding.org>
+
+:py:mod:`obihead` command is in some way analog to the standard Unix `head` command.
+It selects the head of  :ref:`a sequence file<the-sequence-files>`. 
+But instead of working text line by text line as the standard tool, 
+selection is done at sequence level. You can specify number of sequences to be printed.
+
+.. code-block:: bash
+
+   > obihead -n 150 seq1.fasta > seq2.fasta
+
 
-@author: coissac
 '''
 import sys
 from obitools.format.options import addInOutputOption, sequenceWriterGenerator
