@@ -6,9 +6,6 @@ Created on 24 juin 2009
 @author: coissac
 '''
 
-import re
-from logging import root,DEBUG
-
 from obitools.options import getOptionManager
 from obitools.format.options import addInOutputOption
 
@@ -20,6 +17,13 @@ def addTableOptions(optionManager):
                              default="NA",
                              help="String write in the table for not available value"
                             )
+    optionManager.add_option('','--output-field-separator',
+                             action="store", dest="ofs",
+                             metavar="STRING",
+                             type="string",
+                             default="\t",
+                             help="Field separator for CSV file"
+                            )
     optionManager.add_option('-o','--output-seq',
                              action="store_true", dest="sequence",
                              metavar="<NOT AVAILABLE STRING>",
@@ -116,40 +120,43 @@ if __name__=='__main__':
     omit = set(options.omit)
     headers=list(headers)
     headers.sort(headerCmp)
-        
-    print "id",
+    
+    
+    OFS = options.ofs
+    
+    s = "id"
     if options.definition:
-        print '\tdefinition',
+        s = '%s%sdefinition'%(s,OFS)
 
     for k in headers:
         if type(k) is str:
             if k not in omit:
-                print '\t',k,
+                s = '%s%s%s'%(s,OFS,k)
         else:
             if k[0][0:7] not in omit:
                 if k[0][0:7]=='merged_':
-                    print '\t%s:%s' % (k[0][7:],str(k[1])),
+                    s = '%s%s%s:%s' % (s,OFS,k[0][7:],str(k[1]))
                 else:
-                    print '\t%s:%s' % (k[0],str(k[1])),
+                    s = '%s%s%s:%s' % (s,OFS,k[0],str(k[1]))
             
     if options.sequence:
-        print "\tsequence",
-    print 
-        
+        s = "%s%ssequence"%(s,OFS)
+    print s
+    
     
     for seq in db:
-        print seq.id,
+        s = seq.id
         
         if options.definition:
-            print '\t',seq.definition,
+            s = '%s%s%s'%(s,OFS,seq.definition)
             
         for k in headers:
             if type(k) is str:
                 if k not in omit:
                     if k in seq:
-                        print '\t',seq[k],
+                        s = '%s%s%s'%(s,OFS,seq[k])
                     else:
-                        print '\t',options.NA,
+                        s = '%s%s%s'%(s,OFS,options.NA)
             else:
                 if k[0] not in omit:
                     if k[0] in seq:
@@ -157,16 +164,17 @@ if __name__=='__main__':
                     else:
                         sk={}
                     if k[1] in sk:
-                        print '\t',sk[k[1]],
+                        s = '%s%s%s'%(s,OFS,sk[k[1]])
                     else:
                         if k[0][0:7]=='merged_':
-                            print '\t',0,
+                            s = '%s%s0'%(s,OFS)
                         else:
-                            print '\t',options.NA,
+                            s = '%s%s%s'%(s,OFS,options.NA)
         if options.sequence:
-            print '\t',str(seq)
-        else:
-            print
+            s = '%s%s%s'%(s,OFS,str(seq))
+        
+        print s
+        
     
             
         
