@@ -421,21 +421,25 @@ class TaxonomyDump(Taxonomy):
         print >>sys.stderr,"Reading taxonomy dump file..."
             # (taxid,rank,parent)
         taxonomy=[[n[0],n[2],n[1]] for n in nodes]
+        
         print >>sys.stderr,"List all taxonomy rank..."    
         ranks =list(set(x[1] for x in taxonomy))
         ranks.sort()
         rankidx = dict(map(None,ranks,xrange(len(ranks))))
         
-        print >>sys.stderr,"Sorting taxons..."
-        taxonomy.sort(TaxonomyDump._taxonCmp)
+        # EC: Taxa are sorted by taxid in node.dmp file
+        # No need to sort them
+        
+        #print >>sys.stderr,"Sorting taxons..."
+        #taxonomy.sort(TaxonomyDump._taxonCmp)
 
         self._taxonomy=taxonomy
         self._localtaxon=len(taxonomy)
     
         print >>sys.stderr,"Indexing taxonomy..."
         index = {}
-        for t in self._taxonomy:
-            index[t[0]]=self._bsearchTaxon(t[0])
+        for i in xrange(self._localtaxon):
+            index[self._taxonomy[i][0]]=i
         
         print >>sys.stderr,"Indexing parent and rank..."
         for t in self._taxonomy:
