@@ -16,9 +16,16 @@ from obitools.format.options import addInputFormatOption, addInOutputOption,\
     autoEntriesIterator
 import time
     
+from _options import fileWithProgressBar, \
+                     currentInputFileName, \
+                     currentInputFile, \
+                     currentFileSize, \
+                     currentFileTell, \
+                     allEntryIterator
+                     
 
 
-def getOptionManager(optionDefinitions,entryIterator=None,progdoc=None):
+def getOptionManager(optionDefinitions,entryIterator=None,progdoc=None,checkFormat=False):
     '''
     Build an option manager fonction. that is able to parse
     command line options of the script.
@@ -50,88 +57,31 @@ def getOptionManager(optionDefinitions,entryIterator=None,progdoc=None):
                       default=True,
                       help="desactivate progress bar")
 
-    checkFormat=False
     for f in optionDefinitions:
         if f == addInputFormatOption or f == addInOutputOption:
             checkFormat=True 
         f(parser)
         
+        
     def commandLineAnalyzer():
         options,files = parser.parse_args()
         if options.debug:
             logging.root.setLevel(logging.DEBUG)
             
         if checkFormat:
+            if not hasattr(options, "skiperror"):
+                options.skiperror=False
             ei=autoEntriesIterator(options)
         else:
             ei=entryIterator
         
+            
+        options.readerIterator=ei
+        
         i = allEntryIterator(files,ei,with_progress=options.progressbar)
         return options,i
     
     return commandLineAnalyzer
 
-_currentInputFileName=None
-_currentFile = None
-_currentFileSize = None
 
-def currentInputFileName():
-    return _currentInputFileName
-
-def currentInputFile():
-    return _currentFile
-
-def currentFileSize():
-    return _currentFileSize
-
-def currentFileTell():
-    return universalTell(_currentFile)
-
-def fileWithProgressBar(file,step=100):
-    try:
-        size = currentFileSize()
-    except:
-        size = None
-                
-    def fileBar():
-        pos=1
-        progressBar(pos, size, True,currentInputFileName())
-        for l in file:
-            progressBar(currentFileTell,size,head=currentInputFileName())
-            yield l 
-        print >>sys.stderr,''    
-    if size is None:
-        return file
-    else:
-        f = fileBar()
-        return f
-
-
-def allEntryIterator(files,entryIterator,with_progress=False,histo_step=102):
-    global _currentFile
-    global _currentInputFileName
-    global _currentFileSize
-    if files :
-        for f in files:
-            _currentInputFileName=f
-            f = universalOpen(f)
-            _currentFile=f
-            _currentFileSize=fileSize(_currentFile)
-            debug(f)
-            if with_progress:
-                f=fileWithProgressBar(f,step=histo_step)
-            if entryIterator is None:
-                for line in f:
-                    yield line
-            else:
-                for entry in entryIterator(f):
-                    yield entry
-    else:
-        if entryIterator is None:
-            for line in sys.stdin:
-                yield line
-        else:
-            for entry in entryIterator(sys.stdin):
-                yield entry
-            
-            
\ No newline at end of file
+        
\ No newline at end of file
