@@ -1,7 +1,8 @@
 import re
 
 from obitools.options.taxonomyfilter import addTaxonomyFilterOptions
-from obitools.options.taxonomyfilter import taxonomyFilterGenerator
+
+from _bioseqfilter import filterGenerator,sequenceFilterIteratorGenerator
     
 def _sequenceOptionCallback(options,opt,value,parser):
     parser.values.sequencePattern = re.compile(value,re.I)
@@ -49,6 +50,13 @@ def addSequenceFilteringOptions(optionManager):
                                   "the identifier of the sequence. "
                                   "The pattern is case sensitive")
     
+    optionManager.add_option('--id-list',
+                             action="store", dest="idlist",
+                             metavar="<FILENAME>",
+                             type="string",
+                             default=None,
+                             help="file containing identifiers of sequences to select")
+
     optionManager.add_option('-a','--attribute',
                              action="callback", callback=_attributeOptionCallback,
                              type="string",
@@ -106,74 +114,6 @@ def addSequenceFilteringOptions(optionManager):
     
                              
 
-def filterGenerator(options):
-    taxfilter = taxonomyFilterGenerator(options)
-    
-    def sequenceFilter(seq):
-        good = True
-        
-        if hasattr(options, 'sequencePattern'):
-            good = bool(options.sequencePattern.search(str(seq)))
-        
-        if good and hasattr(options, 'identifierPattern'):
-            good = bool(options.identifierPattern.search(seq.id))
-            
-        if good and hasattr(options, 'definitionPattern'):
-            good = bool(options.definitionPattern.search(seq.definition))
-            
-        if good :
-            good = reduce(lambda x,y:x and y,
-                           (k in seq for k in options.has_attribute),
-                           True)
-            
-        if good and hasattr(options, 'attributePatterns'):
-            good = (reduce(lambda x,y : x and y,
-                           (bool(options.attributePatterns[p].search(str(seq[p])))
-                            for p in options.attributePatterns
-                             if p in seq),True)
-                    and
-                    reduce(lambda x,y : x and y,
-                           (bool(p in seq)
-                            for p in options.attributePatterns),True)
-                   )
-            
-        if good and hasattr(options, 'predicats') and options.predicats is not None:
-            if options.taxonomy is not None:
-                e = {'taxonomy' : options.taxonomy,'sequence':seq}
-            else:
-                e = {'sequence':seq}
-                
-            good = (reduce(lambda x,y: x and y,
-                           (bool(eval(p,e,seq))
-                            for p in options.predicats),True)
-                   )
-
-        if good and hasattr(options, 'lmin') and options.lmin is not None:
-            good = len(seq) >= options.lmin
-            
-        if good and hasattr(options, 'lmax') and options.lmax is not None:
-            good = len(seq) <= options.lmax
-        
-        if good:
-            good = taxfilter(seq)
-            
-        if hasattr(options, 'invertedFilter') and options.invertedFilter:
-            good=not good
-                       
-        
-        return good
-    
-    return sequenceFilter
-
-def sequenceFilterIteratorGenerator(options):
-    filter = filterGenerator(options)
-    
-    def sequenceFilterIterator(seqIterator):
-        for seq in seqIterator:
-            if filter(seq):
-                yield seq
-            
-    return sequenceFilterIterator
     
    
     
\ No newline at end of file
