@@ -35,10 +35,12 @@ def mergeTaxonomyClassification(uniqSeq,taxonomy):
             seq['rank']=taxonomy.getRank(seq['taxid'])
             seq['scientific_name']=fa_sn = taxonomy.getScientificName(seq['taxid'])
 
-def uniqSequence(seqIterator,taxonomy=None,mergedKey=None,mergeIds=False):
+def uniqSequence(seqIterator,taxonomy=None,mergedKey=None,mergeIds=False,categories=None):
     uniques={}
     uniqSeq=[]
      
+    if categories is None:
+        categories=[]
     
     if mergedKey is not None:
         mergedKey=set(mergedKey)
@@ -49,7 +51,7 @@ def uniqSequence(seqIterator,taxonomy=None,mergedKey=None,mergeIds=False):
         mergedKey.add('taxid')
                 
     for seq in seqIterator:    
-        s = str(seq)
+        s = tuple(seq[x] for x in categories) + (str(seq),)
         if s in uniques:
             s = uniques[s]
             if 'count' in seq:
@@ -111,8 +113,11 @@ def uniqSequence(seqIterator,taxonomy=None,mergedKey=None,mergeIds=False):
 
     return uniqSeq
 
-def uniqPrefixSequence(seqIterator,taxonomy=None,mergedKey=None,mergeIds=False):
+def uniqPrefixSequence(seqIterator,taxonomy=None,mergedKey=None,mergeIds=False,categories=None):
 
+    if categories is None:
+        categories=[]
+    
     def cmpseq(s1,s2):
         return cmp(str(s1),str(s2))
 
