@@ -23,11 +23,13 @@ the base qualities) together with the qualities for each base of the reported co
 
 '''
 
-from obitools.options import getOptionManager
+from obitools.options import getOptionManager, allEntryIterator
 from obitools.fastq import fastqSolexaIterator, formatFastq
 from obitools.align import QSolexaReverseAssemble
 from obitools.align import QSolexaRightReverseAssemble
 from obitools.tools._solexapairend import buildConsensus
+from obitools.format.options import addInputFormatOption,addOutputFormatOption,\
+    sequenceWriterGenerator
 
 from itertools import chain
 
@@ -35,10 +37,28 @@ def addSolexaPairEndOptions(optionManager):
     optionManager.add_option('-r','--reverse-reads',
                              action="store", dest="reverse",
                              metavar="<FILENAME>",
-                             type="string",
+                             type="str",
                              default=None,
                              help="Filename containing reverse solexa reads "
                             )
+    optionManager.add_option('--sanger',
+                             action="store_const", dest="seqinformat",
+                             default=None,
+                             const='sanger',
+                             help="input file is in sanger fastq nucleic format (standard fastq)")
+
+    optionManager.add_option('--solexa',
+                             action="store_const", dest="seqinformat",
+                             default=None,
+                             const='solexa',
+                             help="input file is in fastq nucleic format produced by solexa sequencer")
+
+    optionManager.add_option('--illumina',
+                             action="store_const", dest="seqinformat",
+                             default=None,
+                             const='illumina',
+                             help="input file is in fastq nucleic format produced by old solexa sequencer")
+
     
 
 def cutDirectReverse(entries):
@@ -83,10 +103,13 @@ def buildAlignment(sequences):
     for d,r in sequences:
         if len(d)==0 or len(r)==0:
             continue
+        
         la.seqA=d 
         la.seqB=r 
         ali=la()
         ali.direction='left'
+        
+        
         if not checkAlignOk(ali):
 #            print >>sys.stderr,"-> bad : -------------------------"
 #            print >>sys.stderr,ali
@@ -103,8 +126,8 @@ def buildAlignment(sequences):
     
     
 if __name__ == '__main__':
-    optionParser = getOptionManager([addSolexaPairEndOptions],
-                                    entryIterator=fastqSolexaIterator
+    optionParser = getOptionManager([addSolexaPairEndOptions,addOutputFormatOption],checkFormat=True
+#                                    entryIterator=fastqSolexaIterator
                                     )
     
     (options, direct) = optionParser()
@@ -112,12 +135,14 @@ if __name__ == '__main__':
     if options.reverse is None:
         sequences=cutDirectReverse(direct)
     else:
-        reverse = fastqSolexaIterator(options.reverse)
+        reverse = allEntryIterator([options.reverse],options.readerIterator)
         sequences=seqPairs(direct,reverse)
+        
+    writer = sequenceWriterGenerator(options)
     
     for ali in buildAlignment(sequences):
         consensus = buildConsensus(ali)
-        print formatFastq(consensus)
+        writer(consensus)
         
         
 
